@@ -153,7 +153,6 @@ add_MaCor = function(model_file,
           model_file[to_modify] <-
             paste0('// derived latent states\n',
                    'LV[1] = ',
-                   if(drift){ 'drift + '} else {NULL},
                    'trend_mus[ytimes_trend[1, 1:n_lv]] + error[1];\n',
                    if(add_ma){
                      'epsilon[1] = error[1];\n'
@@ -167,7 +166,7 @@ add_MaCor = function(model_file,
                      '// full AR process\n'
                    },
                    'LV[i] = ',
-                   if(drift){ 'drift + '} else {NULL},
+                   if(drift){ 'drift * (i - 1) + '} else {NULL},
                    'trend_mus[ytimes_trend[i, 1:n_lv]] + ',
                    if(trend_model == 'AR1'){ 'ar1 .* '} else {NULL},
                    '(LV[i - 1] - trend_mus[ytimes_trend[i - 1, 1:n_lv]])',
@@ -191,7 +190,6 @@ add_MaCor = function(model_file,
           model_file[to_modify] <-
             paste0('// derived latent states\n',
                    'LV[1] = ',
-                   if(drift){ 'drift + '} else {NULL},
                    'trend_mus[ytimes_trend[1, 1:n_lv]] + error[1];\n',
                    if(add_ma){
                      paste0('epsilon[1] = error[1];\n',
@@ -217,7 +215,7 @@ add_MaCor = function(model_file,
                      '// full AR process\n'
                    },
                    'LV[i] = ',
-                   if(drift){ 'drift + '} else {NULL},
+                   if(drift){ 'drift * (i - 1) + '} else {NULL},
                    'trend_mus[ytimes_trend[i, 1:n_lv]] + ',
                    'ar1 .* (LV[i - 1] - trend_mus[ytimes_trend[i - 1, 1:n_lv]]) + ',
                    'ar2 .* (LV[i - 2] - trend_mus[ytimes_trend[i - 2, 1:n_lv]]) + ',
@@ -241,7 +239,6 @@ add_MaCor = function(model_file,
           model_file[to_modify] <-
             paste0('// derived latent states\n',
                    'LV[1] = ',
-                   if(drift){ 'drift + '} else {NULL},
                    'trend_mus[ytimes_trend[1, 1:n_lv]] + error[1];\n',
                    if(add_ma){
                      paste0('epsilon[1] = error[1];\n',
@@ -260,7 +257,7 @@ add_MaCor = function(model_file,
                      'error[2];\n'
                    },
                    'LV[3] = ',
-                   if(drift){ 'drift + '} else {NULL},
+                   if(drift){ 'drift * 2 + '} else {NULL},
                    'trend_mus[ytimes_trend[3, 1:n_lv]] + ',
                    'ar1 .* (LV[2] - trend_mus[ytimes_trend[2, 1:n_lv]]) + ',
                    'ar2 .* (LV[1] - trend_mus[ytimes_trend[1, 1:n_lv]]) + ',
@@ -278,7 +275,7 @@ add_MaCor = function(model_file,
                      '// full AR process\n'
                    },
                    'LV[i] = ',
-                   if(drift){ 'drift + '} else {NULL},
+                   if(drift){ 'drift * (i - 1) + '} else {NULL},
                    'trend_mus[ytimes_trend[i, 1:n_lv]] + ',
                    'ar1 .* (LV[i - 1] - trend_mus[ytimes_trend[i - 1, 1:n_lv]]) + ',
                    'ar2 .* (LV[i - 2] - trend_mus[ytimes_trend[i - 2, 1:n_lv]]) + ',
@@ -305,7 +302,6 @@ add_MaCor = function(model_file,
             paste0('// derived latent states\n',
                    'for(j in 1:n_lv){\n',
                    'LV[1, j] = ',
-                   if(drift){ 'drift[j] + '} else {NULL},
                    'trend_mus[ytimes_trend[1, j]] + error[1, j];\n',
                    'epsilon[1, j] = error[1, j];\n',
                    'for(i in 2:n){\n',
@@ -313,7 +309,7 @@ add_MaCor = function(model_file,
                    'epsilon[i, j] = theta[j] * error[i-1, j];\n',
                    '// full ARMA process\n',
                    'LV[i, j] = ',
-                   if(drift){ 'drift[j] + '} else {NULL},
+                   if(drift){ 'drift[j] * (i - 1) + '} else {NULL},
                    'trend_mus[ytimes_trend[i, j]] + ',
                    if(trend_model == 'AR1'){ 'ar1[j] * '} else {NULL},
                    '(LV[i - 1, j] - trend_mus[ytimes_trend[i - 1, j]]) + ',
@@ -334,7 +330,6 @@ add_MaCor = function(model_file,
             paste0('// derived latent states\n',
                    'for(j in 1:n_lv){\n',
                    'LV[1, j] = ',
-                   if(drift){ 'drift[j] + '} else {NULL},
                    'trend_mus[ytimes_trend[1, j]] + error[1, j];\n',
                    'epsilon[1, j] = error[1, j];\n',
                    'epsilon[2, j] = theta[j] * error[1, j];\n',
@@ -348,7 +343,7 @@ add_MaCor = function(model_file,
                    'epsilon[i, j] = theta[j] * error[i-1, j];\n',
                    '// full ARMA process\n',
                    'LV[i, j] = ',
-                   if(drift){ 'drift[j] + '} else {NULL},
+                   if(drift){ 'drift[j] * (i - 1) + '} else {NULL},
                    'trend_mus[ytimes_trend[i, j]] + ',
                    'ar1[j] * (LV[i - 1, j] - trend_mus[ytimes_trend[i - 1, j]]) + ',
                    'ar2[j] * (LV[i - 2, j] - trend_mus[ytimes_trend[i - 2, j]]) + ',
@@ -369,7 +364,6 @@ add_MaCor = function(model_file,
             paste0('// derived latent states\n',
                    'for(j in 1:n_lv){\n',
                    'LV[1, j] = ',
-                   if(drift){ 'drift[j] + '} else {NULL},
                    'trend_mus[ytimes_trend[1, j]] + error[1, j];\n',
                    'epsilon[1, j] = error[1, j];\n',
                    'epsilon[2, j] = theta[j] * error[1, j];\n',
@@ -380,7 +374,7 @@ add_MaCor = function(model_file,
                    'ar1[j] * (LV[1, j] - trend_mus[ytimes_trend[1, j]]) + ',
                    'epsilon[2, j] + error[2, j];\n',
                    'LV[3, j] = ',
-                   if(drift){ 'drift[j] + '} else {NULL},
+                   if(drift){ 'drift[j] * 2 + '} else {NULL},
                    'trend_mus[ytimes_trend[1, j]] + ',
                    'ar1[j] * (LV[2, j] - trend_mus[ytimes_trend[2, j]]) + ',
                    'ar2[j] * (LV[1, j] - trend_mus[ytimes_trend[1, j]]) + ',
@@ -390,7 +384,7 @@ add_MaCor = function(model_file,
                    'epsilon[i, j] = theta[j] * error[i-1, j];\n',
                    '// full ARMA process\n',
                    'LV[i, j] = ',
-                   if(drift){ 'drift[j] + '} else {NULL},
+                   if(drift){ 'drift[j] * (i - 1) + '} else {NULL},
                    'trend_mus[ytimes_trend[i, j]] + ',
                    'ar1[j] * (LV[i - 1, j] - trend_mus[ytimes_trend[i - 1, j]]) + ',
                    'ar2[j] * (LV[i - 2, j] - trend_mus[ytimes_trend[i - 2, j]]) + ',
@@ -446,7 +440,6 @@ add_MaCor = function(model_file,
             paste0(model_file[insert_line],
                    '\n// derived latent states\n',
                    'trend_raw[1] = ',
-                   if(drift){ 'drift + '} else {NULL},
                    'error[1];\n',
                    if(add_ma){
                      'epsilon[1] = error[1];\n'
@@ -462,7 +455,7 @@ add_MaCor = function(model_file,
                      paste0('// full AR process\n')
                    },
                    'trend_raw[i] = ',
-                   if(drift){ 'drift + '} else {NULL},
+                   if(drift){ 'drift * (i - 1) + '} else {NULL},
                    if(trend_model == 'AR1'){ 'ar1 .* '} else {NULL},
                    'trend_raw[i - 1] + ',
                    if(add_ma){
@@ -487,7 +480,6 @@ add_MaCor = function(model_file,
             paste0(model_file[insert_line],
                    '\n// derived latent states\n',
                    'trend_raw[1] = ',
-                   if(drift){ 'drift + '} else {NULL},
                    'error[1];\n',
                    if(add_ma){
                      paste0('epsilon[1] = error[1];\n',
@@ -512,7 +504,7 @@ add_MaCor = function(model_file,
                      '// full AR process\n'
                    },
                    'trend_raw[i] = ',
-                   if(drift){ 'drift + '} else {NULL},
+                   if(drift){ 'drift * (i - 1) + '} else {NULL},
                    'ar1 .* trend_raw[i - 1] + ',
                    'ar2 .* trend_raw[i - 2] + ',
                    if(add_ma){
@@ -537,7 +529,6 @@ add_MaCor = function(model_file,
             paste0(model_file[insert_line],
                    '\n// derived latent states\n',
                    'trend_raw[1] = ',
-                   if(drift){ 'drift + '} else {NULL},
                    'error[1];\n',
                    if(add_ma){
                      paste0('epsilon[1] = error[1];\n',
@@ -555,7 +546,7 @@ add_MaCor = function(model_file,
                      'error[2];\n'
                    },
                    'trend_raw[3] = ',
-                   if(drift){ 'drift + '} else {NULL},
+                   if(drift){ 'drift * 2 + '} else {NULL},
                    'ar1 .* trend_raw[2] + ',
                    'ar2 .* trend_raw[1] + ',
                    if(add_ma){
@@ -572,7 +563,7 @@ add_MaCor = function(model_file,
                      '// full AR process\n'
                    },
                    'trend_raw[i] = ',
-                   if(drift){ 'drift + '} else {NULL},
+                   if(drift){ 'drift * (i - 1) + '} else {NULL},
                    'ar1 .* trend_raw[i - 1] + ',
                    'ar2 .* trend_raw[i - 2] + ',
                    'ar3 .* trend_raw[i - 3] + ',
@@ -599,7 +590,6 @@ add_MaCor = function(model_file,
             paste0(model_file[insert_line],
                    '\nfor(j in 1:n_series){\n',
                    'trend[1, j] = ',
-                   if(drift){ 'drift[j] + '} else {NULL},
                    'error[1, j];\n',
                    'epsilon[1, j] = error[1, j];\n',
                    'for(i in 2:n){\n',
@@ -607,7 +597,7 @@ add_MaCor = function(model_file,
                    'epsilon[i, j] = theta[j] * error[i-1, j];\n',
                    '// full ARMA process\n',
                    'trend[i, j] = ',
-                   if(drift){ 'drift[j] + '} else {NULL},
+                   if(drift){ 'drift[j] * (i - 1) + '} else {NULL},
                    if(trend_model == 'AR1'){ 'ar1[j] * '} else {NULL},
                    'trend[i - 1, j] + ',
                    'epsilon[i, j] + error[i, j];\n',
@@ -628,7 +618,6 @@ add_MaCor = function(model_file,
             paste0(model_file[insert_line],
                    '\nfor(j in 1:n_series){\n',
                    'trend[1, j] = ',
-                   if(drift){ 'drift[j] + '} else {NULL},
                    'error[1, j];\n',
                    'epsilon[1, j] = error[1, j];\n',
                    'epsilon[2, j] = theta[j] * error[1, j];\n',
@@ -641,7 +630,7 @@ add_MaCor = function(model_file,
                    'epsilon[i, j] = theta[j] * error[i-1, j];\n',
                    '// full ARMA process\n',
                    'trend[i, j] = ',
-                   if(drift){ 'drift[j] + '} else {NULL},
+                   if(drift){ 'drift[j] * (i - 1) + '} else {NULL},
                    'ar1[j] * trend[i - 1, j] + ',
                    'ar2[j] * trend[i - 2, j] + ',
                    'epsilon[i, j] + error[i, j];\n',
@@ -662,7 +651,6 @@ add_MaCor = function(model_file,
             paste0(model_file[insert_line],
                    '\nfor(j in 1:n_series){\n',
                    'trend[1, j] = ',
-                   if(drift){ 'drift[j] + '} else {NULL},
                    'error[1, j];\n',
                    'epsilon[1, j] = error[1, j];\n',
                    'epsilon[2, j] = theta[j] * error[1, j];\n',
@@ -672,7 +660,7 @@ add_MaCor = function(model_file,
                    'ar1[j] * trend[1, j] + ',
                    'epsilon[2, j] + error[2, j];\n',
                    'trend[3, j] = ',
-                   if(drift){ 'drift[j] + '} else {NULL},
+                   if(drift){ 'drift[j] * 2 + '} else {NULL},
                    'ar1[j] * trend[2, j] + ',
                    'ar2[j] * trend[1, j] + ',
                    'epsilon[2, j] + error[2, j];\n',
@@ -681,7 +669,7 @@ add_MaCor = function(model_file,
                    'epsilon[i, j] = theta[j] * error[i-1, j];\n',
                    '// full ARMA process\n',
                    'trend[i, j] = ',
-                   if(drift){ 'drift[j] + '} else {NULL},
+                   if(drift){ 'drift[j] * (i - 1) + '} else {NULL},
                    'ar1[j] * trend[i - 1, j] + ',
                    'ar2[j] * trend[i - 2, j] + ',
                    'ar3[j] * trend[i - 3, j] + ',
