@@ -17,4 +17,4 @@ utils::globalVariables(c("y", "year", "smooth_vals", "smooth_num",
                          "name", "needed", "nmix_trendmap", "orig_formula",
                          "trial", "use_var1", "use_var1cor", "xcols_drop",
                          "time_lag", "dis_time", "maxt", "orig_rows",
-                         "matches", "time.", "file_name"))
+                         "matches", "time.", "file_name", ".data"))
