@@ -1,14 +1,17 @@
-## ----echo = FALSE------------------------------------------------------
-NOT_CRAN <- identical(tolower(Sys.getenv("NOT_CRAN")), "true")
+params <-
+list(EVAL = TRUE)
+
+## ---- echo = FALSE------------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
-  purl = NOT_CRAN,
-  eval = NOT_CRAN
+  message = FALSE,
+  warning = FALSE,
+  eval = if (isTRUE(exists("params"))) params$EVAL else FALSE
 )
 
 
-## ----setup, include=FALSE----------------------------------------------
+## ----setup, include=FALSE-----------------------------------------------------
 knitr::opts_chunk$set(
   echo = TRUE,   
   dpi = 100,
@@ -21,33 +24,33 @@ library(ggplot2)
 theme_set(theme_bw(base_size = 12, base_family = 'serif'))
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 simdat <- sim_mvgam(n_series = 4, T = 24, prop_missing = 0.2)
 head(simdat$data_train, 16)
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 class(simdat$data_train$series)
 levels(simdat$data_train$series)
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 all(levels(simdat$data_train$series) %in% unique(simdat$data_train$series))
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 summary(glm(y ~ series + time,
             data = simdat$data_train,
             family = poisson()))
 
 
-## ----------------------------------------------------------------------
-summary(gam(y ~ series + s(time, by = series),
+## -----------------------------------------------------------------------------
+summary(mgcv::gam(y ~ series + s(time, by = series),
             data = simdat$data_train,
             family = poisson()))
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 gauss_dat <- data.frame(outcome = rnorm(10),
                         series = factor('series1',
                                         levels = 'series1'),
@@ -55,19 +58,19 @@ gauss_dat <- data.frame(outcome = rnorm(10),
 gauss_dat
 
 
-## ----------------------------------------------------------------------
-gam(outcome ~ time,
+## -----------------------------------------------------------------------------
+mgcv::gam(outcome ~ time,
     family = betar(),
     data = gauss_dat)
 
 
-## ----error=TRUE--------------------------------------------------------
+## ----error=TRUE---------------------------------------------------------------
 mvgam(outcome ~ time,
       family = betar(),
       data = gauss_dat)
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # A function to ensure all timepoints within a sequence are identical
 all_times_avail = function(time, min_time, max_time){
     identical(as.numeric(sort(time)),
@@ -92,20 +95,20 @@ if(any(checked_times$all_there == FALSE)){
 }
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 bad_times <- data.frame(time = seq(1, 16, by = 2),
                         series = factor('series_1'),
                         outcome = rnorm(8))
 bad_times
 
 
-## ----error = TRUE------------------------------------------------------
+## ----error = TRUE-------------------------------------------------------------
 get_mvgam_priors(outcome ~ 1,
                  data = bad_times,
                  family = gaussian())
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 bad_times %>%
   dplyr::right_join(expand.grid(time = seq(min(bad_times$time),
                                            max(bad_times$time)),
@@ -115,13 +118,13 @@ bad_times %>%
 good_times
 
 
-## ----error = TRUE------------------------------------------------------
+## ----error = TRUE-------------------------------------------------------------
 get_mvgam_priors(outcome ~ 1,
                  data = good_times,
                  family = gaussian())
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 bad_levels <- data.frame(time = 1:8,
                         series = factor('series_1',
                                         levels = c('series_1',
@@ -131,29 +134,29 @@ bad_levels <- data.frame(time = 1:8,
 levels(bad_levels$series)
 
 
-## ----error = TRUE------------------------------------------------------
+## ----error = TRUE-------------------------------------------------------------
 get_mvgam_priors(outcome ~ 1,
                  data = bad_levels,
                  family = gaussian())
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 setdiff(levels(bad_levels$series), unique(bad_levels$series))
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 bad_levels %>%
   dplyr::mutate(series = droplevels(series)) -> good_levels
 levels(good_levels$series)
 
 
-## ----error = TRUE------------------------------------------------------
+## ----error = TRUE-------------------------------------------------------------
 get_mvgam_priors(outcome ~ 1,
                  data = good_levels,
                  family = gaussian())
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 miss_dat <- data.frame(outcome = rnorm(10),
                        cov = c(NA, rnorm(9)),
                        series = factor('series1',
@@ -162,13 +165,13 @@ miss_dat <- data.frame(outcome = rnorm(10),
 miss_dat
 
 
-## ----error = TRUE------------------------------------------------------
+## ----error = TRUE-------------------------------------------------------------
 get_mvgam_priors(outcome ~ cov,
                  data = miss_dat,
                  family = gaussian())
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 miss_dat <- list(outcome = rnorm(10),
                  series = factor('series1',
                                  levels = 'series1'),
@@ -177,44 +180,44 @@ miss_dat$cov <- matrix(rnorm(50), ncol = 5, nrow = 10)
 miss_dat$cov[2,3] <- NA
 
 
-## ----error=TRUE--------------------------------------------------------
+## ----error=TRUE---------------------------------------------------------------
 get_mvgam_priors(outcome ~ cov,
                  data = miss_dat,
                  family = gaussian())
 
 
-## ----fig.alt = "Plotting time series features for GAM models in mvgam"----
+## ---- fig.alt = "Plotting time series features for GAM models in mvgam"-------
 plot_mvgam_series(data = simdat$data_train, 
                   y = 'y', 
                   series = 'all')
 
 
-## ----fig.alt = "Plotting time series features for GAM models in mvgam"----
+## ---- fig.alt = "Plotting time series features for GAM models in mvgam"-------
 plot_mvgam_series(data = simdat$data_train, 
                   y = 'y', 
                   series = 1)
 
 
-## ----fig.alt = "Plotting time series features for GAM models in mvgam"----
+## ---- fig.alt = "Plotting time series features for GAM models in mvgam"-------
 plot_mvgam_series(data = simdat$data_train,
                   newdata = simdat$data_test,
                   y = 'y', 
                   series = 1)
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 data("all_neon_tick_data")
 str(dplyr::ungroup(all_neon_tick_data))
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 plotIDs <- c('SCBI_013','SCBI_002',
              'SERC_001','SERC_005',
              'SERC_006','SERC_012',
              'BLAN_012','BLAN_005')
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 model_dat <- all_neon_tick_data %>%
   dplyr::ungroup() %>%
   dplyr::mutate(target = ixodes_scapularis) %>%
@@ -223,7 +226,7 @@ model_dat <- all_neon_tick_data %>%
   dplyr::mutate(epiWeek = as.numeric(epiWeek))
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 model_dat %>%
   # Create all possible combos of plotID, Year and epiWeek; 
   # missing outcomes will be filled in as NA
@@ -238,7 +241,7 @@ model_dat %>%
                      dplyr::distinct()) -> model_dat
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 model_dat %>%
   dplyr::mutate(series = plotID,
                 y = target) %>%
@@ -248,7 +251,7 @@ model_dat %>%
   dplyr::arrange(Year, epiWeek, series) -> model_dat 
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 model_dat %>%
   dplyr::ungroup() %>%
   dplyr::group_by(series) %>%
@@ -257,17 +260,17 @@ model_dat %>%
   dplyr::ungroup() -> model_dat
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 levels(model_dat$series)
 
 
-## ----error=TRUE--------------------------------------------------------
+## ----error=TRUE---------------------------------------------------------------
 get_mvgam_priors(y ~ 1,
                  data = model_dat,
                  family = poisson())
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 testmod <- mvgam(y ~ s(epiWeek, by = series, bs = 'cc') +
                    s(series, bs = 're'),
                  trend_model = 'AR1',
@@ -276,10 +279,10 @@ testmod <- mvgam(y ~ s(epiWeek, by = series, bs = 'cc') +
                  run_model = FALSE)
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 str(testmod$model_data)
 
 
-## ----------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 code(testmod)
 
